@@ -325,57 +325,50 @@ extend_or_shorten_line <- function(line, dist, ab_xy_nml) {
 #+ Get plot data
 #++++++++++++++++++++++++++++++++++++
 get_trial_plot_data <- function(tot_plot_length, min_plot_length, max_plot_length) {
+
   #* +++++++++++++++++++++++++++++++++++
   #* For debugging
   #* +++++++++++++++++++++++++++++++++++
-  # tot_plot_length <- 2500
-  # min_plot_length <- 260
-  # max_plot_length <- 300
+
+  # tot_plot_length <- final_exp_plots$tot_plot_length[[5]]
+  # min_plot_length <- 73.152
+  # max_plot_length <- 91.44
 
   #* +++++++++++++++++++++++++++++++++++
   #* Main
   #* +++++++++++++++++++++++++++++++++++
-  mean_plot_length <- (min_plot_length + max_plot_length) / 2
-  num_comp_plots <- tot_plot_length %/% mean_plot_length
+  #--- use minimum length to start ---#
+  num_comp_plots <- tot_plot_length %/% min_plot_length
+  #--- find remainder of available plot length ---#
   remainder <- tot_plot_length %% min_plot_length
 
-  #--- number of plots (comp + 1) ---#
-  plot_length_s <- tot_plot_length / (num_comp_plots + 1)
-  #--- number of plots (comp) ---#
-  plot_length_l <- tot_plot_length / (num_comp_plots)
+  #--- how much additional length can be added to each plot ---#
+  additional_length <- remainder / num_comp_plots
 
-  if (plot_length_s > min_plot_length & plot_length_s < max_plot_length) {
-    #--- if the average length satisfy the condition ---#
-    return_data <-
-      data.table::data.table(
-        plot_id = seq_len(num_comp_plots + 1),
-        plot_length = plot_length_s
-      )
-    return(return_data)
-  } else if (plot_length_l > min_plot_length & plot_length_l < max_plot_length) {
+  if (length(num_comp_plots) == 0 | num_comp_plots == 0) {
+    return_data <- NULL
+  } else if (additional_length + min_plot_length > max_plot_length) {
+    #--- in this case there is more length than can be used with max plot length ---#
+    #--- thus, we will use the max ---#
     return_data <-
       data.table::data.table(
         plot_id = seq_len(num_comp_plots),
-        plot_length = plot_length_l
+        plot_length = max_plot_length
       )
-    return(return_data)
   } else {
-    num_comp_plots <- tot_plot_length %/% min_plot_length
-
-    if (num_comp_plots == 0) {
-      return_data <- NULL
-    } else {
-      return_data <-
-        data.table::data.table(
-          plot_id = seq_len(num_comp_plots),
-          plot_length = min_plot_length
-        )
-    }
+    #--- here the additional length plus the minimum plot length do not exceed the max length ---#
+    #--- can divide up the remainder among the plots ---#
+    return_data <-
+      data.table::data.table(
+        plot_id = seq_len(num_comp_plots),
+        plot_length = (min_plot_length + additional_length)
+      )
   }
 
   return(return_data)
 }
 
+
 # get_plot_data <- function(tot_plot_length, min_plot_length, mean_length) {
 #   num_comp_plots <- tot_plot_length %/% mean_length
 #   remainder <- tot_plot_length %% mean_length
